import { Strapi } from "@strapi/strapi";
import dayjs from "dayjs";

export default {
  task: async ({ strapi }: { strapi: Strapi }) => {
    const orders: any = await strapi.entityService.findMany(
      "api::order.order",
      {
        filters: {
          orderStatus: "shipping",
          orderTime: {
            $lt: dayjs().subtract(7, "day").toDate(),
          },
        },
        populate: "products.product",
      }
    );

    if (!orders) return;
    const ids = orders?.map((order) => order.id);
    const idsProducts = orders
      ?.map((order) => order.products.map((product) => product.product))
      .flat();

    // Update order status
    await strapi.db.query("api::order.order").updateMany({
      where: {
        id: {
          $in: ids,
        },
      },
      data: {
        orderStatus: "completed",
      },
    });

    // Update product sold quantity
     idsProducts.map(async (product) => {
      const sold = product.sold + 1;
      await strapi.db.query("api::product.product").update({
        where: {
          id: product.id,
        },
        data: {
          sold: sold,
        },
      });
    });
  },
  options: {
    rule: `*/${process.env.TIME_CRON_TASK} * * * * *`,
  },
};
